@@ -6,6 +6,11 @@
 // warning: 'AVCaptureDeviceTypeExternalUnknown' is deprecated
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
+#ifdef MAC_OS_VERSION_14_0
+// To make fastfetch compiled on newer macOS versions runs on older ones
+AVF_EXPORT __attribute__((weak_import)) AVCaptureDeviceType const AVCaptureDeviceTypeExternal;
+#endif
+
 const char* ffDetectCamera(FFlist* result)
 {
     #ifdef MAC_OS_X_VERSION_10_15
